import { ISearchProviderRegistry } from '@jupyterlab/documentsearch';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { INotebookShell } from '@jupyter-notebook/application';
const SEARCHABLE_CLASS = 'jp-mod-searchable';
/**
 * A plugin to programmatically disable the Crtl-F shortcut in Jupyter Notebook
 * See https://github.com/jupyterlab/retrolab/pull/294 and
 * https://github.com/jupyterlab/jupyterlab/issues/11754 for more context.
 */
const disableShortcut = {
    id: '@jupyter-notebook/documentsearch-extension:disableShortcut',
    requires: [ISettingRegistry],
    autoStart: true,
    activate: async (app, registry) => {
        var _a, _b;
        const docSearchShortcut = (_b = (_a = registry.plugins['@jupyterlab/documentsearch-extension:plugin']) === null || _a === void 0 ? void 0 : _a.schema['jupyter.lab.shortcuts']) === null || _b === void 0 ? void 0 : _b.find(shortcut => shortcut.command === 'documentsearch:start');
        if (docSearchShortcut) {
            docSearchShortcut.disabled = true;
            docSearchShortcut.keys = [];
        }
    }
};
/**
 * A plugin to add document search functionalities.
 */
const notebookShellWidgetListener = {
    id: '@jupyter-notebook/documentsearch-extension:notebookShellWidgetListener',
    requires: [INotebookShell, ISearchProviderRegistry],
    autoStart: true,
    activate: (app, notebookShell, registry) => {
        // If a given widget is searchable, apply the searchable class.
        // If it's not searchable, remove the class.
        const transformWidgetSearchability = (widget) => {
            if (!widget) {
                return;
            }
            const providerForWidget = registry.getProviderForWidget(widget);
            if (providerForWidget) {
                widget.addClass(SEARCHABLE_CLASS);
            }
            if (!providerForWidget) {
                widget.removeClass(SEARCHABLE_CLASS);
            }
        };
        // Update searchability of the active widget when the registry
        // changes, in case a provider for the current widget was added
        // or removed
        registry.changed.connect(() => transformWidgetSearchability(notebookShell.currentWidget));
        // Apply the searchable class only to the active widget if it is actually
        // searchable. Remove the searchable class from a widget when it's
        // no longer active.
        notebookShell.currentChanged.connect((_, args) => {
            if (notebookShell.currentWidget) {
                transformWidgetSearchability(notebookShell.currentWidget);
            }
        });
    }
};
/**
 * Export the plugins as default.
 */
const plugins = [
    disableShortcut,
    notebookShellWidgetListener
];
export default plugins;
